/*
 * Copyright (c) 2023 - 2024. KeyWare.Co.Ltd All rights reserved.
 * 项目名称：C++ 信息安全性设计准则
 * 项目描述：用于检查C++源代码的安全性设计准则的Sonarqube插件
 * 版权说明：本软件属北京关键科技股份有限公司所有，在未获得北京关键科技股份有限公司正式授权情况下，任何企业和个人，不能获取、阅读、安装、传播本软件涉及的任何受知识产权保护的内容。
 */
package com.keyware.sonar.cxx.rules.checkers;

import com.sonar.cxx.sslr.api.AstNode;
import com.sonar.cxx.sslr.api.Grammar;
import org.sonar.check.Priority;
import org.sonar.check.Rule;
import org.sonar.cxx.parser.CxxGrammarImpl;
import org.sonar.cxx.squidbridge.annotations.ActivatedByDefault;
import org.sonar.cxx.squidbridge.annotations.SqaleConstantRemediation;
import org.sonar.cxx.squidbridge.checks.SquidCheck;

import javax.annotation.Nullable;
import java.util.List;


/**
 * TODO FVNRPassWordChecker
 *
 * @author RenFengJiang
 * @date 2024/1/14
 */
@Rule(key = "FVNRPassWordChecker", name = "应使用单向不可逆算法对密码进行加密", description = "应使用单向加密算法对口令进行加密并存储", priority = Priority.INFO, tags = {"28suo"})
@ActivatedByDefault
@SqaleConstantRemediation("5min")
public class FVNRPassWordChecker extends SquidCheck<Grammar> {
    @Override
    public void init() {
        // 订阅要检查AST节点类型，用于在visitNode方法中检查该类型节点
        this.subscribeTo(
                CxxGrammarImpl.translationUnit
        );
    }


    public void visitFile(@Nullable AstNode astNode) {
        //逐行获取内容
        List<String> inputFileLines = getContext().getInputFileLines();
        for (String str:inputFileLines) {
            if(str.startsWith("#include")){
                if(str.contains("<openssl/aes.h>")){
                    getContext().createFileViolation(this, "应使用单向不可逆算法对密码进行加密");
                }else if(str.contains("<openssl/des.h>")){
                    getContext().createFileViolation(this, "应使用单向不可逆算法对密码进行加密");
                }
            }
        }
    }
}
